==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/TokenHookResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.TokenHookResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TokenHookResponseCommandsInner
 */
@JsonPropertyOrder({ TokenHookResponseCommandsInner.JSON_PROPERTY_TYPE,
        TokenHookResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("TokenHookResponse_commands_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TokenHookResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<TokenHookResponseCommandsInnerValueInner> value = null;

    public TokenHookResponseCommandsInner() {
    }

    public TokenHookResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * One of the supported commands: &#x60;com.okta.identity.patch&#x60;: Modify an ID token
     * &#x60;com.okta.access.patch&#x60;: Modify an access token &gt; **Note:** The &#x60;commands&#x60; array should
     * only contain commands that can be applied to the requested tokens. For example, if only an ID token is requested,
     * the &#x60;commands&#x60; array shouldn&#39;t contain commands of the type &#x60;com.okta.access.patch&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "One of the supported commands:   `com.okta.identity.patch`: Modify an ID token   `com.okta.access.patch`: Modify an access token > **Note:** The `commands` array should only contain commands that can be applied to the requested tokens. For example, if only an ID token is requested, the `commands` array shouldn't contain commands of the type `com.okta.access.patch`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public TokenHookResponseCommandsInner value(List<TokenHookResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public TokenHookResponseCommandsInner addvalueItem(TokenHookResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * The &#x60;value&#x60; object is where you specify the operation to perform. It&#39;s an array, which allows you
     * to request more than one operation.
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `value` object is where you specify the operation to perform. It's an array, which allows you to request more than one operation.")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<TokenHookResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<TokenHookResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TokenHookResponseCommandsInner tokenHookResponseCommandsInner = (TokenHookResponseCommandsInner) o;
        return Objects.equals(this.type, tokenHookResponseCommandsInner.type)
                && Objects.equals(this.value, tokenHookResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TokenHookResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/TokenHookResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.TokenHookResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TokenHookResponseCommandsInner
 */
@JsonPropertyOrder({ TokenHookResponseCommandsInner.JSON_PROPERTY_TYPE,
        TokenHookResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("TokenHookResponse_commands_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TokenHookResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<TokenHookResponseCommandsInnerValueInner> value = null;

    public TokenHookResponseCommandsInner() {
    }

    public TokenHookResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * One of the supported commands: &#x60;com.okta.identity.patch&#x60;: Modify an ID token
     * &#x60;com.okta.access.patch&#x60;: Modify an access token &gt; **Note:** The &#x60;commands&#x60; array should
     * only contain commands that can be applied to the requested tokens. For example, if only an ID token is requested,
     * the &#x60;commands&#x60; array shouldn&#39;t contain commands of the type &#x60;com.okta.access.patch&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "One of the supported commands:   `com.okta.identity.patch`: Modify an ID token   `com.okta.access.patch`: Modify an access token > **Note:** The `commands` array should only contain commands that can be applied to the requested tokens. For example, if only an ID token is requested, the `commands` array shouldn't contain commands of the type `com.okta.access.patch`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public TokenHookResponseCommandsInner value(List<TokenHookResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public TokenHookResponseCommandsInner addvalueItem(TokenHookResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * The &#x60;value&#x60; object is where you specify the operation to perform. It&#39;s an array, which allows you
     * to request more than one operation.
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `value` object is where you specify the operation to perform. It's an array, which allows you to request more than one operation.")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<TokenHookResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<TokenHookResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TokenHookResponseCommandsInner tokenHookResponseCommandsInner = (TokenHookResponseCommandsInner) o;
        return Objects.equals(this.type, tokenHookResponseCommandsInner.type)
                && Objects.equals(this.value, tokenHookResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TokenHookResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
